package com.xyzc.common.core.utils;

import com.xyzc.common.core.exception.ErrorCode;
import com.xyzc.common.core.exception.ServerException;

import java.util.List;

public class AssertUtils {

    /**
     * 判断对象是否为空，为空抛出异常
     *
     * @param o       普通对象
     * @param errCode 错误码
     */
    public static void notNull(Object o, ErrorCode errCode) {
        if (o == null) {
            throw new ServerException(errCode);
        }
    }

    /**
     * 判断数组长度是否为1，不唯一抛出异常
     *
     * @param list    数组长度
     * @param errCode 错误码
     */
    public static void isUnique(List list, ErrorCode errCode) {
        if (list == null || list.size() != 1) {
            throw new ServerException(errCode);
        }
    }

    /**
     * 判断boolean值
     *
     * @param flag    boolean值
     * @param errCode 错误码
     */
    public static void isTrue(Boolean flag, ErrorCode errCode) {
        if (!flag) {
            throw new ServerException(errCode);
        }
    }

    /**
     * 判断对象是否为空，不为空抛出异常
     *
     * @param o       Object
     * @param errCode ErrorCode
     */
    public static void isNull(Object o, ErrorCode errCode) {
        if (o != null) {
            throw new ServerException(errCode);
        }
    }

    /**
     * 判断剩余燃料是否大于0，小于0抛出异常
     *
     * @param surplusFuel
     */
    public static void surplusFuel(Long surplusFuel) {
        if (surplusFuel < 0) {
            throw new ServerException(ErrorCode.SURPLUS_FUEL_NOT_ENOUGH);
        }
    }
}
