package com.xyzc.common.oss.utils;

import cn.hutool.core.util.StrUtil;
import com.xyzc.common.core.exception.ServerException;
import com.xyzc.common.core.utils.StringUtils;
import com.xyzc.common.oss.entity.UploadResult;
import com.xyzc.common.oss.factory.OssFactory;
import org.springframework.web.multipart.MultipartFile;

import java.io.IOException;

/**
 * oss 工具类
 *
 * @author yz
 * @date 2024/7/12 上午11:07
 */
public class OssUtils {

    /**
     * 上传文件 并返回 ossUrl
     *
     * @param file 文件
     * @return ossUrl
     */
    public static String upload(MultipartFile file) {
        String fileName = file.getOriginalFilename();
        if (StrUtil.isBlank(fileName)) {
            throw new ServerException("文件名不能为空");
        }
        String suffix = StringUtils.substring(fileName, fileName.lastIndexOf(StrUtil.DOT), fileName.length());
        UploadResult uploadResult;
        try {
            uploadResult = OssFactory.instance().uploadSuffix(file.getBytes(), suffix);
        } catch (IOException e) {
            throw new ServerException(e.getMessage());
        }
        return uploadResult.getUrl();
    }

    /**
     * 删除文件
     *
     * @param path oss路径
     */
    public static void deleteOss(String path) {
        OssFactory.instance().delete(path);
    }

}
