package com.xyzc.common.sms.service.impl;

import com.xyzc.common.core.exception.ErrorCode;
import com.xyzc.common.core.exception.ServerException;
import com.xyzc.common.sms.cache.SmsSendCache;
import com.xyzc.common.sms.service.ISmsService;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.dromara.sms4j.api.SmsBlend;
import org.dromara.sms4j.comm.exception.SmsBlendException;
import org.dromara.sms4j.core.factory.SmsFactory;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.util.LinkedHashMap;

/**
 * 短信服务
 *
 * @author 墨凡
 */
@Service
@Slf4j
@RequiredArgsConstructor
public class SmsServiceImpl implements ISmsService {
    private final SmsSendCache smsSendCache;

    @Value("${sms.blends.config1.template-id}")
    private String templateId;

    /**
     * 发送短信
     *
     * @param mobile 手机号
     * @return 是否发送成功
     */
    @Override
    public boolean sendCode(String mobile, String key, String value) {
        LinkedHashMap<String, String> map = new LinkedHashMap<>(1);
        map.put(key, value);
        SmsBlend smsBlend = SmsFactory.getSmsBlend("config1");

        try {
            smsBlend.sendMessage(mobile, templateId, map);
        } catch (SmsBlendException e) {
            // 发送短信
            log.error("验证码短信发送异常 => {}", e.message);
            throw new ServerException(ErrorCode.SEND_MOBILE_FAST);
        }
        // 放入缓存
        smsSendCache.saveCode(mobile, value);
        return true;
    }

    @Override
    public boolean verifyCode(String mobile, String code) {
        String value = smsSendCache.getCode(mobile);
        // redis 有值，且值与输入的值一致
        if (value != null && value.equalsIgnoreCase(code)) {
            // 删除短信验证码
            smsSendCache.deleteCode(mobile);
            // 效验成功
            return true;
        }
        return false;
    }
}
