package com.xyzc.common.web.security.cache;

import com.xyzc.common.redis.cache.RedisCache;
import com.xyzc.common.redis.cache.RedisKeys;
import com.xyzc.common.web.security.user.UserDetail;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Component;

/**
 * 认证 Cache
 *
 * @author 杨兴卓
 * date: 2024/7/22 0:05
 */
@Component
@AllArgsConstructor
public class TokenStoreCache {

    private final RedisCache redisCache;

    public void saveUser(String accessToken, UserDetail user) {
        String key = RedisKeys.getAccessTokenKey(accessToken);
        redisCache.set(key, user);
    }

    public UserDetail getUser(String accessToken) {
        String key = RedisKeys.getAccessTokenKey(accessToken);
        return (UserDetail) redisCache.get(key);
    }

    public void deleteUser(String accessToken) {
        String key = RedisKeys.getAccessTokenKey(accessToken);
        redisCache.delete(key);
    }

    public void refreshExpire(String accessToken) {
        String key = RedisKeys.getAccessTokenKey(accessToken);
        redisCache.refreshExpire(key);
    }
}
