package com.xyzc.common.web.security.mobile;

import org.springframework.beans.factory.InitializingBean;
import org.springframework.context.MessageSource;
import org.springframework.context.MessageSourceAware;
import org.springframework.context.support.MessageSourceAccessor;
import org.springframework.security.authentication.AuthenticationProvider;
import org.springframework.security.authentication.BadCredentialsException;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.AuthenticationException;
import org.springframework.security.core.SpringSecurityMessageSource;
import org.springframework.security.core.userdetails.UserDetails;
import org.springframework.security.core.userdetails.UsernameNotFoundException;
import org.springframework.util.Assert;

public class WeiXinScanAuthenticationProvider implements AuthenticationProvider, InitializingBean, MessageSourceAware {

    private final WeiXinScanUserDetailService weiXinScanUserDetailService;
    protected MessageSourceAccessor messages = SpringSecurityMessageSource.getAccessor();

    public WeiXinScanAuthenticationProvider(WeiXinScanUserDetailService weiXinScanUserDetailService) {
        this.weiXinScanUserDetailService = weiXinScanUserDetailService;
    }

    @Override
    public void afterPropertiesSet() throws Exception {
        Assert.notNull(weiXinScanUserDetailService, "weiXinScanUserDetailService must not be null");
    }

    @Override
    public void setMessageSource(MessageSource messageSource) {
        this.messages = new MessageSourceAccessor(messageSource);
    }

    @Override
    public Authentication authenticate(Authentication authentication) throws AuthenticationException {
        Assert.isInstanceOf(WeiXinScanAuthenticationToken.class, authentication,
                () -> messages.getMessage(
                        "WeiXinScanAuthenticationToken.onlySupports",
                        "Only MobileAuthenticationProvider is supported"));

        WeiXinScanAuthenticationToken authenticationToken = (WeiXinScanAuthenticationToken) authentication;
        String openId = authenticationToken.getName();
        Long agentId = (Long) authenticationToken.getCredentials();

        try {
            UserDetails userDetails = weiXinScanUserDetailService.loadUserByOpenidAndAgentId(openId, agentId);
            if (userDetails == null) {
                throw new BadCredentialsException("Bad credentials");
            }
            return createSuccessAuthentication(authentication, userDetails);
        } catch (UsernameNotFoundException ex) {
            throw new BadCredentialsException(this.messages
                    .getMessage("MobileAuthenticationProvider.badCredentials", "Bad credentials"));
        }
    }

    protected Authentication createSuccessAuthentication(Authentication authentication, UserDetails user) {
        WeiXinScanAuthenticationToken result = new WeiXinScanAuthenticationToken(user, null,
                null);
        result.setDetails(authentication.getDetails());
        return result;
    }

    @Override
    public boolean supports(Class<?> authentication) {
        return WeiXinScanAuthenticationToken.class.isAssignableFrom(authentication);
    }
}
