package com.xyzc.common.weixin.mp.config;

import com.xyzc.common.weixin.mp.config.properties.WxMpProperties;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import me.chanjar.weixin.common.redis.RedissonWxRedisOps;
import me.chanjar.weixin.mp.api.WxMpService;
import me.chanjar.weixin.mp.api.impl.WxMpServiceImpl;
import me.chanjar.weixin.mp.config.impl.WxMpDefaultConfigImpl;
import me.chanjar.weixin.mp.config.impl.WxMpRedisConfigImpl;
import org.apache.http.HttpResponse;
import org.apache.http.client.HttpClient;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.entity.StringEntity;
import org.apache.http.impl.client.HttpClients;
import org.apache.http.util.EntityUtils;
import org.redisson.api.RedissonClient;
import org.springframework.boot.configurationprocessor.json.JSONObject;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import java.util.List;
import java.util.stream.Collectors;


/**
 * @author yz
 * @date 2024-04-11 上午 8:42
 */
@Slf4j
@Configuration
@RequiredArgsConstructor
public class WxMpConfig {

    private final WxMpProperties wxMpProperties;
    private final RedissonClient redissonClient;

    /**
     * wx mp 配置初始化
     */
    @Bean
    public WxMpService wxMpService() {
        final List<WxMpProperties.MpConfig> configs = this.wxMpProperties.getConfigs();
        if (configs == null) {
            throw new RuntimeException("微信公众号配置异常");
        }

        WxMpService service = new WxMpServiceImpl();
        service.setMultiConfigStorages(configs
            .stream().map(a -> {
                // 配置 redis 缓存 access key
                RedissonWxRedisOps redissonWxRedisOps = new RedissonWxRedisOps(redissonClient);
                WxMpDefaultConfigImpl configStorage =
                    new WxMpRedisConfigImpl(redissonWxRedisOps, a.getAppId());
                configStorage.setAppId(a.getAppId());
                configStorage.setSecret(a.getSecret());
                configStorage.setToken(a.getToken());
                configStorage.setAesKey(a.getAesKey());
                return configStorage;
            }).collect(Collectors.toMap(WxMpDefaultConfigImpl::getAppId, a -> a, (o, n) -> o)));
        log.info("初始化微信公众号配置");
        return service;
    }



}
