package com.xyzc.start.controller;

import com.xyzc.common.core.utils.Result;
import com.xyzc.start.domain.WebAppGroup;
import com.xyzc.start.domain.vo.IndustryVo;
import com.xyzc.start.domain.vo.WebAppGroupVo;
import com.xyzc.start.service.IAppPageService;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 应用
 *
 * @author 杨兴卓
 */
@RestController
@RequestMapping("/appPage")
@RequiredArgsConstructor
@CrossOrigin
public class AppPageController {

    private final IAppPageService appPageService;

    /**
     * 行业列表
     *
     * @return
     */
    @GetMapping("/byIndustry")
    public Result<List<IndustryVo>> byIndustry() {
        List<IndustryVo> industryList = appPageService.queryByIndustry();

        return Result.ok(industryList);
    }

    /**
     * 按具体行业分类的app列表
     */
    @GetMapping("/byIndustry/{industryId}")
    public Result<List<WebAppGroupVo>> byIndustry(@PathVariable("industryId") Long industryId) {
        List<WebAppGroupVo> appList = appPageService.queryByIndustryId(industryId);

        return Result.ok(appList);
    }

    /**
     * 类型列表
     */
    @GetMapping("/byType")
    public Result<List<WebAppGroupVo>> byType() {
        List<WebAppGroupVo> appList = appPageService.queryByType();

        return Result.ok(appList);
    }

    /**
     * 按具体类型分类的app列表
     */
    @GetMapping("/byType/{typeId}")
    public Result<List<WebAppGroupVo>> byType(@PathVariable("typeId") Long typeId) {
        List<WebAppGroupVo> appList = appPageService.queryByTypeId(typeId);

        return Result.ok(appList);
    }


    /**
     * 根据id返回聊天类app
     *
     * @return Result<Void>
     */
    @GetMapping("/chat/{id}")
    public Result<Void> queryChatAppById(@PathVariable("id") Long id) {

        return Result.ok();
    }


    /**
     * 根据id返回AI文生图app
     */
    @GetMapping("/txtToPhoto/{id}")
    public Result<Void> queryAiGroupPhotoById(@PathVariable("id") Long id) {

        return Result.ok();
    }

    /**
     * 根据id返回AI图生图app
     */
    @GetMapping("/photoToPhoto/{id}")
    public Result<Void> queryAiPhotoGroupPhotoById(@PathVariable("id") Long id) {

        return Result.ok();
    }

    /**
     * 根据id返回AI数字人app
     */
    @GetMapping("/digitalHuman/{id}")
    public Result<Void> queryAiDigitalHumanById(@PathVariable("id") Long id) {

        return Result.ok();
    }

}
