package com.xyzc.start.controller;

import com.xyzc.common.core.utils.Result;
import com.xyzc.start.domain.HelpCommon;
import com.xyzc.start.domain.bo.HelpFeedbackBo;
import com.xyzc.start.service.IHelpPageService;
import lombok.RequiredArgsConstructor;
import org.hibernate.validator.constraints.Range;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 帮助页面
 *
 * @author 杨兴卓
 */

@RestController
@RequestMapping("/help")
@RequiredArgsConstructor
@CrossOrigin
public class HelpPageController {

    private final IHelpPageService helpPageService;

    /**
     * 用户反馈问题
     * @param helpFeedbackBo
     * @return
     */
    @PostMapping("/submit")
    public Result<Void> submit(@RequestBody HelpFeedbackBo helpFeedbackBo) {
        helpPageService.submit(helpFeedbackBo);
        return Result.ok();
    }

    /**
     * 所查询文档是否有帮助，0，无帮助， 1，有帮助
     */
    @GetMapping("/helper")
    public Result<Void> setHelper(@RequestParam("id") Long id, @Range(min=0, max = 1, message = "反馈类型错误") @RequestParam("status") Integer status){
        helpPageService.setHelper(id, status);
        return Result.ok();
    }

    /**
     * 查询常见问题
     * @param
     * @return
     */
    @GetMapping("/queryMember")
    public Result<List<HelpCommon>> queryHelpDocById(Long id) {
        List<HelpCommon> helpCommonList = helpPageService.queryHelpDocById(id);

        return Result.ok(helpCommonList);
    }

}
