package com.xyzc.start.controller;

import com.xyzc.common.core.utils.Result;
import com.xyzc.start.domain.App;
import com.xyzc.start.domain.vo.*;
import com.xyzc.start.service.IHomePageService;
import lombok.AllArgsConstructor;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * 首页
 *
 * @author 杨兴卓
 */
@RestController
@RequestMapping("/homePage")
@AllArgsConstructor
@CrossOrigin
public class HomePageController {

    private final IHomePageService homePageService;


    /**
     * 首页信息
     *
     * @return
     */
    @GetMapping("/query")
    public Result<WebHomePageVo> query() {
        WebHomePageVo homePage = homePageService.getHomePage();

        return Result.ok(homePage);
    }


    /**
     * 更多最近使用应用
     */
    @GetMapping("/moreUse")
    public Result<List<BaseUserCollectAppVo>> recentlyUsed(Long appId) {
        List<BaseUserCollectAppVo> list = homePageService.getRecentlyUsed(appId);

        return Result.ok(list);
    }

    /**
     * 更多收藏应用
     */
    @GetMapping("/moreCollect")
    public Result<List<BaseUserCollectAppVo>> moreCollect(Long appId) {
        List<BaseUserCollectAppVo> list = homePageService.getMoreCollect(appId);

        return Result.ok(list);
    }

    /**
     * 更多精选应用
     */
    @GetMapping("/moreSelector")
    public Result<List<BaseUserSelectAppVo>> moreSelect(Long appId) {
        List<BaseUserSelectAppVo> list = homePageService.getMoreSelector(appId);

        return Result.ok(list);
    }

    /**
     * 应用详情
     */
    @GetMapping("/clickApp")
    public Result<App> clickApp(Long appId) {
//        App app = homePageService.clickApp(appId);

        return Result.ok();
    }

}
