package com.xyzc.start.controller;


import com.xyzc.common.core.utils.Result;
import com.xyzc.start.domain.vo.BaseUserPhotoFolderVo;
import com.xyzc.start.service.IUserInfoService;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 我的画夹
 *
 * @author 杨兴卓
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("/myPhotoFolder")
@CrossOrigin
public class MyPhotoFolderController {

    private final IUserInfoService userInfoService;

    /**
     * 我的画夹
     *
     * @return 画夹
     */
    @GetMapping("/photoFolder")
    public Result<List<BaseUserPhotoFolderVo>> photoFolder(Long id) {
        List<BaseUserPhotoFolderVo> photoFolder = userInfoService.photoFolder(id);
        return Result.ok(photoFolder);
    }

    /**
     * 单个图画的详细信息
     *
     * @return 单个图画的详细信息
     */
    @GetMapping("/photo/{id}")
    public Result<BaseUserPhotoFolderVo> photoFolderDetail(@PathVariable("id") Long id) {
        BaseUserPhotoFolderVo baseUserPhotoFolderVo = userInfoService.queryPhotoById(id);

        return Result.ok(baseUserPhotoFolderVo);
    }

    /**
     * 删除指定图画
     */
    @DeleteMapping("/photo/{id}")
    public Result<Void> deletePhoto(@PathVariable("id") Long id) {
        userInfoService.deletePhoto(id);
        return Result.ok();
    }

    /**
     * 批量删除图画
     *
     * @param ids 图画id集合
     * @return 是否成功
     */
    @DeleteMapping("/photo")
    public Result<Void> deletePhotos(@RequestBody List<Long> ids) {
        userInfoService.deletePhotos(ids);
        return Result.ok();
    }

}
