package com.xyzc.start.controller;

import com.xyzc.common.core.utils.Result;
import com.xyzc.start.domain.FuelPackage;
import com.xyzc.start.domain.MemberCard;
import com.xyzc.start.domain.vo.AiModelVo;
import com.xyzc.start.domain.vo.FuelPackageVo;
import com.xyzc.start.domain.vo.MemberCardVo;
import com.xyzc.start.domain.vo.SchemeVo;
import com.xyzc.start.service.ISchemeService;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 套餐购买
 *
 * @author 杨兴卓
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("/scheme")
@CrossOrigin
public class SchemeController {

    private final ISchemeService schemeService;

    /**
     * 会员卡生效套餐信息
     */
    @GetMapping("/currentMember")
    public Result<SchemeVo> current() {
        SchemeVo scheme = schemeService.getCurrentMember();

        return Result.ok(scheme);
    }


    /**
     * id查询会员卡详细套餐
     */
    @GetMapping("/currentMember/{memberId}")
    public Result<MemberCardVo> currentMemberById(@RequestParam("memberId") Long memberId) {
        MemberCardVo memberCard = schemeService.queryCurrentMemberById(memberId);

        return Result.ok(memberCard);
    }

    /**
     * 燃料包生效套餐信息
     */
    @GetMapping("/currentFuel")
    public Result<SchemeVo> currentFuel() {
        SchemeVo scheme = schemeService.getCurrentFuel();

        return Result.ok(scheme);
    }

    /**
     * id查询燃料包详细套餐
     */
    @GetMapping("/currentFuel/{fuelId}")
    public Result<FuelPackageVo> currentFuelById(@RequestParam("fuelId") Long fuelId) {
        FuelPackageVo fuelPackage = schemeService.queryCurrentFuelById(fuelId);

        return Result.ok(fuelPackage);
    }

    /**
     * 燃料规则
     *
     * @param modelId 模型id
     */
    @GetMapping("/fuelLaw")
    public Result<List<AiModelVo>> queryfuelLawList(Long modelId) {
        List<AiModelVo> fuelPackageList = schemeService.queryModelLawList(modelId);

        return Result.ok(fuelPackageList);
    }

}
