package com.xyzc.start.controller;

import cn.hutool.core.text.PasswdStrength;
import com.xyzc.common.core.utils.Result;
import com.xyzc.start.domain.bo.BaseUserLoginBo;
import com.xyzc.start.domain.bo.UserMobileLoginBO;
import com.xyzc.start.domain.vo.AccessTokenVo;
import com.xyzc.start.domain.vo.CaptchaVO;
import com.xyzc.start.service.ICaptchaService;
import com.xyzc.start.service.IUserAuthService;
import jakarta.validation.Valid;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

/**
 * 用户认证管理
 * 前端访问路由地址为: /user/auth
 *
 * @author 杨兴卓
 * @date 2024/7/21 22:39
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("/user")
//@CrossOrigin(origins = "*")
@CrossOrigin
public class UserAuthController {

    private final IUserAuthService userAuthService;
    private final ICaptchaService captchaService;


    /**
     * 获取验证码
     *
     * @return Result<CaptchaVO>
     */
    @GetMapping("captcha")
    public Result<CaptchaVO> captcha() {
        CaptchaVO captchaVO = captchaService.generate();

        return Result.ok(captchaVO);
    }

    /**
     * 密码登录
     *
     * @param login BaseUserLoginBo
     * @return Result<BaseUserTokenVo>
     */
    @PostMapping("login")
    public Result<AccessTokenVo> login(@RequestBody BaseUserLoginBo login) {
        AccessTokenVo token = userAuthService.loginByAccount(login);

        return Result.ok(token);
    }

    /**
     * 发送短信
     *
     * @param mobileLoginBo
     * @return
     */
    @PostMapping("send/code")
    public Result<String> sendCode(@RequestBody @Valid UserMobileLoginBO mobileLoginBo) {
        boolean flag = userAuthService.sendCode(mobileLoginBo);
        if (!flag) {
            return Result.error("短信发送失败！");
        }

        return Result.ok();
    }

    /**
     * 手机短信登录
     *
     * @param login
     * @return
     */
    @PostMapping("mobile")
    public Result<AccessTokenVo> mobile(@RequestBody @Valid UserMobileLoginBO login) {
        AccessTokenVo token = userAuthService.loginByMobile(login);

        return Result.ok(token);
    }

    /**
     * 用户账号注册
     *
     * @param register
     * @return
     */
    @PostMapping("register")
    public Result<String> register(@RequestBody @Valid BaseUserLoginBo register) {
        int level = PasswdStrength.check(register.getPassword());
        if (level == 0) {
            return Result.error("密码需包含数字、字母、特殊字符中的2种");
        }
        userAuthService.register(register);
        return Result.ok();
    }

}
