package com.xyzc.start.controller;

import cn.hutool.core.io.FileUtil;
import com.xyzc.common.core.utils.Result;
import com.xyzc.common.core.utils.StringUtils;
import com.xyzc.common.core.utils.file.MimeTypeUtils;
import com.xyzc.common.web.security.user.SecurityUser;
import com.xyzc.resource.api.RemoteFileService;
import com.xyzc.resource.api.domain.RemoteFile;
import com.xyzc.start.constant.FuelDeduct;
import com.xyzc.start.domain.bo.AgentCardSecretBo;
import com.xyzc.start.domain.bo.BaseUserCollectBo;
import com.xyzc.start.domain.bo.HobbyBo;
import com.xyzc.start.domain.vo.AvatarVo;
import com.xyzc.start.domain.vo.BaseUserFuelFlowVo;
import com.xyzc.start.domain.vo.BaseUserVo;
import com.xyzc.start.domain.vo.IndustryVo;
import com.xyzc.start.service.IUserInfoService;
import jakarta.validation.Valid;
import lombok.RequiredArgsConstructor;
import org.apache.dubbo.config.annotation.DubboReference;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.io.IOException;
import java.util.Arrays;
import java.util.List;

/**
 * 用户信息
 *
 * @author 杨兴卓
 */
@RestController
@RequiredArgsConstructor
@CrossOrigin
@RequestMapping("userInfo")
public class UserInfoController {

    private final IUserInfoService userInfoService;

    @DubboReference
    private RemoteFileService remoteFileService;

    /**
     * 登录用户获取用户信息
     */
    @GetMapping("/info")
    public Result<BaseUserVo> info() {
        BaseUserVo baseUserVo = userInfoService.queryInfo();

        return Result.ok(baseUserVo);
    }


    /**
     * 获取当前用户的燃料和会员卡信息
     */
    @GetMapping("/current")
    public Result<BaseUserVo> current() {
        BaseUserVo baseUserVo = userInfoService.queryCurrent();

        return Result.ok(baseUserVo);
    }


    /**
     * 燃料流水
     */
    @GetMapping("/queryFuelFlow")
    public Result<List<BaseUserFuelFlowVo>> queryFuelFlow(Long flowId) {
        List<BaseUserFuelFlowVo> FuelFlowList = userInfoService.queryFuelFlow(flowId);

        return Result.ok(FuelFlowList);
    }


    /**
     * 用户选择喜好
     */
    @PostMapping("/hobby")
    public Result<Void> hobby(@RequestBody @Valid HobbyBo hobby) {
        userInfoService.saveHobby(hobby);

        return Result.ok();
    }

    /**
     * 根据对应的appId扣减燃料
     */
    @PutMapping("/deduct")
    public Result<String> deduct(Long appId) {
        userInfoService.deduct(appId);

        return Result.ok(FuelDeduct.DEDUCT_SUCCESS);
    }

    /**
     * 获取所有行业
     *
     * @return
     */
    @GetMapping("/queryIndustryAll")
    public Result<List<IndustryVo>> queryIndustryAll() {
        List<IndustryVo> industryAll = userInfoService.getIndustryAll();

        return Result.ok(industryAll);
    }


    /**
     * 销卡
     */
    @PostMapping("/exchange")
    public Result<Void> exchange(@RequestBody @Valid AgentCardSecretBo exchangeBo) {
        userInfoService.exchange(exchangeBo);

        return Result.ok();
    }

    /**
     * 用户收藏或取消
     */
    @PostMapping("/collectOrCancel")
    public Result<String> collectOrCancel(@RequestBody @Valid BaseUserCollectBo collectBo) {
        userInfoService.collectOrCancel(collectBo);

        return Result.ok("操作成功");
    }

}
