package com.xyzc.start.controller;

import com.xyzc.common.core.exception.ErrorCode;
import com.xyzc.common.core.exception.ServerException;
import com.xyzc.common.core.utils.Result;
import com.xyzc.common.core.utils.StringUtils;
import com.xyzc.start.domain.vo.AccessTokenVo;
import com.xyzc.start.domain.vo.TicketVo;
import com.xyzc.start.service.IWeiXinAuthService;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.io.IOException;
import java.nio.charset.StandardCharsets;


/**
 * 微信公众号登录
 * 前端访问路由地址为: /weixin
 *
 * @author 杨兴卓
 * @date 2024-07-26
 */

@RestController
@RequiredArgsConstructor
@RequestMapping("weixin")
@CrossOrigin
public class WeiXinAuthController {

    private final IWeiXinAuthService weiXinAuthService;

    /**
     * 微信网页授权回调接口
     *
     * @param code 微信授权码
     * @return
     */
    @GetMapping("auth")
    public Result<AccessTokenVo> auth(@RequestParam("code") String code, @RequestParam("agentId") Long agentId) {
        AccessTokenVo baseUserTokenVo = weiXinAuthService.auth(code, agentId);

        return Result.ok(baseUserTokenVo);
    }

    /**
     * 获取微信二维码
     */
    @GetMapping("scan")
    public Result<TicketVo> scan(@RequestParam("agentId") Long agentId) {
        TicketVo ticketVo = weiXinAuthService.sacn(agentId);

        return Result.ok(ticketVo);
    }


    /**
     * 获得服务认证
     */
    @GetMapping("getToken")
    public String getToken(HttpServletResponse res,
                           @RequestParam("signature") String signature,
                           @RequestParam("timestamp") String timestamp,
                           @RequestParam("nonce") String nonce,
                           @RequestParam("echostr") String echostr) throws IOException {

        res.setCharacterEncoding(String.valueOf(StandardCharsets.UTF_8));
        res.getWriter().write(echostr);
        res.getWriter().flush();
        res.getWriter().close();

        return echostr;
    }


    /**
     * 处理推送事件
     */
    @PostMapping("getToken")
    public void postToken(HttpServletRequest req,
                          HttpServletResponse res,
                          @RequestParam("signature") String signature,
                          @RequestParam("timestamp") String timestamp,
                          @RequestParam("openid") String openid) {
//        System.out.println("signature: " + signature);
//        System.out.println("timestamp: " + timestamp);
//        System.out.println("openid: " + openid);

        weiXinAuthService.postToken(req, res);

    }


    /**
     * 检查微信扫码状态
     */
    @GetMapping("/wxLogin")
    public Result<AccessTokenVo> checkLoginStatus(String ticket) {
        if (StringUtils.isEmpty(ticket)) {
            throw new ServerException(ErrorCode.QR_CODE_TICKET_NULL);
        }
        AccessTokenVo userTokenVo =  weiXinAuthService.getStatus(ticket);
        return Result.ok(userTokenVo);
    }

}
