package com.xyzc.start.domain.bo;

import cn.hutool.core.lang.RegexPool;
import com.xyzc.common.core.validate.AddGroup;
import com.xyzc.common.core.validate.EditGroup;
import com.xyzc.common.core.xss.Xss;
import com.xyzc.start.domain.Merchant;
import com.xyzc.start.domain.vo.MerchantInfoDTO;
import io.github.linpeilie.annotations.AutoMapper;
import jakarta.validation.constraints.*;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.hibernate.validator.constraints.Range;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 商户业务对象 xy_merchant
 *
 * @author yz
 * @date 2024-07-02
 */
@Data
@EqualsAndHashCode(callSuper = true)
@AutoMapper(target = Merchant.class, reverseConvertGenerate = false)
public class MerchantBo extends MerchantInfoDTO {

    /**
     * 商户id
     */
    @NotNull(message = "商户id不能为空", groups = {EditGroup.class})
    private Long id;

    /**
     * 系统用户id
     */
    private Long userId;

    /**
     * 上级经销商id
     */
    private Long parentDealerId;

    /**
     * 商户类型；1-经销商；2-代理商
     */
    private Integer merType;

    /**
     * 商户名称
     */
    @NotBlank(message = "商户名称不能为空", groups = {AddGroup.class, EditGroup.class})
    private String merName;

    /**
     * 商户编号
     */
    private String merNo;

    /**
     * 联系人
     */
    @NotBlank(message = "联系人不能为空", groups = {AddGroup.class, EditGroup.class})
    private String contacts;

    /**
     * 联系人手机号
     */
    @NotBlank(message = "联系人手机号不能为空", groups = {AddGroup.class, EditGroup.class})
    @Pattern(regexp = RegexPool.MOBILE, message = "请输入正确手机号", groups = {AddGroup.class, EditGroup.class})
    private String contactsPhone;

    /**
     * 用户邮箱
     */
    @Email(message = "邮箱格式不正确")
    @Size(max = 50, message = "邮箱长度不能超过{max}个字符")
    @NotBlank(message = "邮箱不能为空", groups = {AddGroup.class, EditGroup.class})
    private String contactsEmail;

    /**
     * 代理商主体类型：0-无主体；1-有主体
     */
    @Range(min = 0, max = 1, message = "代理商主体类型取值范围在{min}和{max}之间", groups = {AddGroup.class, EditGroup.class})
    private Integer agentBodyType;

    /**
     * 待提现金额
     */
    private BigDecimal waitWithdrawalAmount;

    /**
     * 代收账户金额
     */
    private BigDecimal collectedAccountAmount;

    /**
     * 账户积分
     */
    private Long accountIntegral;

    /**
     * 公司所在地
     */
    private String companyDomicile;

    /**
     * 详细地址
     */
    private String detailAddr;

    /**
     * 合同图片ossId集合
     */
    private List<Long> contractOssIdList;

    /**
     * 合同价格
     */
    private BigDecimal contractAmount;

    /**
     * 合同有效开始时间
     */
    private Date contractBeginTime;

    /**
     * 合同有效结束时间
     */
    private Date contractEndTime;

    /**
     * 合同信用额度
     */
    private BigDecimal contractLineOfCredit;

    /**
     * 发票抬头
     */
    private String invoiceHeader;

    /**
     * 发票类型；1-数据服务
     */
    @Range(min = 1, max = 1, message = "发票类型取值范围在{min}和{max}之间", groups = {AddGroup.class, EditGroup.class})
    private Integer invoiceType;

    /**
     * 收票人手机号
     */
    private String invoicePhone;

    /**
     * 收票人邮箱
     */
    private String invoiceEmail;

    /**
     * 开户名
     */
    private String accountName;

    /**
     * 开户银行
     */
    private String accountBankName;

    /**
     * 银行账号
     */
    private String bankAccountNumber;

    /**
     * 收款码ossId
     */
    private Long QRCodeOssId;

    /**
     * 商户状态；0-停用；1-正常
     */
    private Integer merStatus;

    /**
     * 备注
     */
    private String remark;

    /**
     * 账号
     */
    @NotBlank(message = "账号不能为空", groups = AddGroup.class)
    @Xss(message = "用户账号不能包含脚本字符", groups = AddGroup.class)
    @Size(min = 6, max = 30, message = "用户账号长度在{min}到{max}之间", groups = AddGroup.class)
    private String userName;

    /**
     * 密码
     */
    @NotBlank(message = "密码不能为空", groups = AddGroup.class)
    private String password;


}
