package com.xyzc.start.domain.bo;

import com.xyzc.common.core.validate.AddGroup;
import com.xyzc.common.core.validate.EditGroup;
import com.xyzc.start.domain.WxConfig;
import io.github.linpeilie.annotations.AutoMapper;
import jakarta.validation.constraints.NotBlank;
import jakarta.validation.constraints.NotNull;
import lombok.Data;

/**
 * 微信配置业务对象 xy_wx_config
 *
 * @author yz
 * @date 2024-07-24
 */
@Data
@AutoMapper(target = WxConfig.class, reverseConvertGenerate = false)
public class WxConfigBo {

    /**
     * 微信支付配置id
     */
    @NotNull(message = "微信支付配置id不能为空", groups = {EditGroup.class})
    private Long id;

    /**
     * 商户id
     */
    private Long merId;

    /**
     * 商户系统用户id
     */
    private Long userId;

    /**
     * 微信公众号appid
     */
    @NotBlank(message = "微信公众号appid不能为空", groups = {AddGroup.class, EditGroup.class})
    private String appId;

    /**
     * 微信公众号秘钥
     */
    @NotBlank(message = "微信公众号秘钥不能为空", groups = {AddGroup.class, EditGroup.class})
    private String appSecret;

    /**
     * 微信txt文件url
     */
    private String txtFileOssUrl;

    /**
     * 微信商户id
     */
    @NotBlank(message = "微信商户id不能为空", groups = {AddGroup.class, EditGroup.class})
    private String mchId;

    /**
     * V2 api key
     */
    @NotBlank(message = "V2 api key不能为空", groups = {AddGroup.class, EditGroup.class})
    private String apiV2Key;

    /**
     * V3 api key
     */
    private String apiV3Key;

    /**
     * 证书文件ossUrl
     */
    private String certFileOssUrl;

    /**
     * 证书key文件ossUrl
     */
    private String keyFileOssUrl;

}
