package com.xyzc.start.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.xyzc.common.mybatis.core.mapper.BaseMapperPlus;
import com.xyzc.start.constant.Const;
import com.xyzc.start.domain.BaseUserCollect;
import com.xyzc.start.domain.query.BaseUserCollectQuery;
import com.xyzc.start.domain.vo.*;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * BaseUserCollectMapper
 *
 * @author 墨凡
 * date: 2024/7/21 17:46
 */
@Mapper
public interface BaseUserCollectMapper extends BaseMapperPlus<BaseUserCollect, BaseUserCollectVo> {

    /**
     * 根据条件查询 绘画模型
     *
     * @param bo
     * @return
     */
    List<BaseUserCollectVo> queryDrawModelByBo(@Param(Const.BO) BaseUserCollectQuery bo, @Param("baseUserId") Long baseUserId);

    /**
     * 根据条件查询 图像收藏
     *
     * @param collectBo
     * @return
     */
    List<BaseUserCollectVo> queryImageByBo(BaseUserCollectQuery collectBo, @Param("baseUserId") Long baseUserId);


    /**
     * 根据条件查询 应用收藏
     *
     * @param collectBo
     * @return
     */
    List<BaseUserCollectVo> queryAbilityByBo(BaseUserCollectQuery collectBo, @Param("baseUserId") Long baseUserId);

    /**
     * 根据上一个id，分页查询绘画模型
     *
     * @param userId
     * @param id
     * @return
     */
    List<DrawModelCollectVo> queryDrawModelById(Long userId, Long id);

    /**
     * 根据上一个id，分页查询图像
     *
     * @param userId
     * @param id
     * @return
     */
    List<DrawGraphicsVo> queryDrawGraphicsById(Long userId, Long id);

    /**
     * 根据上一个id，分页查询应用
     *
     * @param userId
     * @param id
     * @return
     */
    List<CollectAppVo> queryAppById(Long userId, Long id);

    /**
     * 根据用户id查询收藏的应用
     *
     * @param userId
     * @return
     */
    List<BaseUserCollectAppVo> queryCollectAppBy(Long userId);

    /**
     * 根据用户id查询浏览记录
     *
     * @param userId
     * @return
     */
    List<BaseUserCollectAppVo> queryHistoryAppBy(Long userId);

    /**
     * 查询精选应用
     *
     * @return
     */
    List<BaseUserSelectAppVo> queryCarefulSelectAppBy(Long appId, Integer length);

    /**
     * 查询该用户是否收藏应用
     *
     * @param userId    用户id
     * @param appIdList 应用id列表
     * @param type      收藏类型
     */
    List<BaseUserCollect> queryCollectAppByUserIdAndAppId(@Param("userId") Long userId, List<Long> appIdList, @Param("type") Integer type);

    /**
     * 查询该用户是否收藏
     *
     * @param userId
     * @param collectId
     * @param type
     */
    BaseUserCollect queryCollectByIdAndCollectId(Long userId, Long collectId, Integer type);
}