package com.xyzc.start.mapper;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.xyzc.common.mybatis.core.mapper.BaseMapperPlus;
import com.xyzc.start.domain.BaseUser;
import com.xyzc.start.domain.bo.HobbyBo;
import com.xyzc.start.domain.vo.BaseUserMemberCardVo;
import com.xyzc.start.domain.vo.BaseUserVo;
import com.xyzc.start.domain.vo.MemberCardVo;

import java.util.List;

/**
 * BaseUserMapper
 *
 * @author 杨兴卓
 */
public interface BaseUserMapper extends BaseMapperPlus<BaseUser, BaseUserVo> {

    /**
     * 根据手机和商户id查询用户
     *
     * @param mobile
     * @return
     */
    default BaseUser queryDetailByMobile(String mobile, Long agentId) {
        return this.selectOne(new LambdaQueryWrapper<BaseUser>()
                .eq(BaseUser::getMobile, mobile)
                .eq(BaseUser::getAgentMerId, agentId)
        );
    }


    /**
     * 根据用户名查询用户
     *
     * @param username
     * @return
     */
    default BaseUser queryDetailByUsername(String username) {
        return this.selectOne(new LambdaQueryWrapper<BaseUser>()
                .eq(BaseUser::getUserName, username)
        );
    }

    /**
     * 根据userId查询会员卡详细信息
     *
     * @param userId
     * @return
     */
    List<BaseUserMemberCardVo> queryDetailMemberCardByUserId(Long userId);

    /**
     * 登录用户获取会员卡大致信息
     *
     * @param userId 用户id
     */
    List<BaseUserMemberCardVo> queryMyMemberCardByUserId(Long userId);

    /**
     * 根据openid和商户id查询用户
     *
     * @param openId
     * @param agentId
     * @return
     */
    default BaseUser queryUserByOpenid(String openId, Long agentId) {
        return this.selectOne(new LambdaQueryWrapper<BaseUser>()
                .eq(BaseUser::getOpenid, openId)
                .eq(BaseUser::getAgentMerId, agentId)
        );
    }

    /**
     * 选择性获取用户信息，燃料，次数
     *
     * @param userId
     * @return
     */
    default BaseUserVo queryCurrentInfo(Long userId) {

        return this.selectVoOne(new LambdaQueryWrapper<BaseUser>()
                .select(BaseUser::getSurplusFuel)
                .eq(BaseUser::getId, userId)
        );
    }

    /**
     * @param userId
     * @param hobby
     */
    void saveHobbys(Long userId, HobbyBo hobby);

    /**
     * 根据用户id查询用户信息
     *
     * @param userId
     * @return
     */
    BaseUserVo queryBaseUserVoById(Long userId);

    /**
     * 获取用户的燃料信息，加上行锁了
     *
     * @param userId
     * @return
     */
    BaseUser selectVoByIdForUpdate(Long userId);
}
