package com.xyzc.start.security;

import com.xyzc.common.core.enums.UserStatusEnum;
import com.xyzc.common.web.security.user.UserDetail;
import com.xyzc.start.convert.BaseUserConvert;
import com.xyzc.start.domain.BaseUser;
import com.xyzc.start.mapper.BaseUserMapper;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.security.core.userdetails.UserDetails;
import org.springframework.security.core.userdetails.UserDetailsService;
import org.springframework.security.core.userdetails.UsernameNotFoundException;
import org.springframework.stereotype.Service;

/**
 * 账号登录 UserDetailsService
 */
@Service
@RequiredArgsConstructor
@Slf4j
public class UserDetailsServiceImpl implements UserDetailsService {

    private final BaseUserMapper baseUserMapper;

    @Override
    public UserDetails loadUserByUsername(String username) throws UsernameNotFoundException {
        BaseUser userEntity = baseUserMapper.queryDetailByUsername(username);
        if (userEntity == null) {
            throw new UsernameNotFoundException("用户名或密码错误");
        }

        // 用户详细信息
        // 转换成UserDetail对象
        UserDetail userDetail = BaseUserConvert.INSTANCE.convertDetail(userEntity);
//        String avater =
//        userDetail.setAvatar(userEntity.getAvatar());

        // 账号不可用
        if (userEntity.getStatus() == UserStatusEnum.DISABLE.getValue()) {
            userDetail.setEnabled(false);
        }
        return userDetail;
    }
}
