package com.xyzc.start.security;

import com.xyzc.common.core.enums.UserStatusEnum;
import com.xyzc.common.web.security.mobile.WeiXinScanUserDetailService;
import com.xyzc.common.web.security.user.UserDetail;
import com.xyzc.start.convert.BaseUserConvert;
import com.xyzc.start.domain.BaseUser;
import com.xyzc.start.mapper.BaseUserMapper;
import lombok.RequiredArgsConstructor;
import org.springframework.security.core.userdetails.UserDetails;
import org.springframework.stereotype.Service;

@Service
@RequiredArgsConstructor
public class WeiXinScanUserDetailServiceImpl implements WeiXinScanUserDetailService {

    private final BaseUserMapper baseUserMapper;

    /**
     * 根据openid获取用户信息
     *
     * @param openid 用户openid
     * @return UserDetails
     */
    @Override
    public UserDetails loadUserByOpenidAndAgentId(String openid, Long agentId) {
        BaseUser userEntity = baseUserMapper.queryUserByOpenid(openid, agentId);
        if (userEntity == null) {
            //用户不存在就创建一个新的用户
            //TODO 后期做用户注册的 代理商校验
            BaseUser baseUser = new BaseUser();
            baseUser.setOpenid(openid);
            baseUser.setUserName(openid);
            baseUser.setAgentMerId(agentId);
            baseUser.setSurplusFuel(10L);
            baseUser.setStatus(0);
            baseUserMapper.insert(baseUser);

            return BaseUserConvert.INSTANCE.convertDetail(baseUser);
        }
        // 用户详细信息
        // 转换成UserDetail对象
        UserDetail userDetail = BaseUserConvert.INSTANCE.convertDetail(userEntity);

        // 账号不可用
        if (userEntity.getStatus() == UserStatusEnum.DISABLE.getValue()) {
            userDetail.setEnabled(false);
        }

        return userDetail;
    }
}
