package com.xyzc.start.service.impl;

import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.xyzc.common.core.exception.ServerException;
import com.xyzc.start.constant.FeedbackConst;
import com.xyzc.start.domain.HelpCommon;
import com.xyzc.start.domain.HelpFeedback;
import com.xyzc.start.domain.bo.HelpFeedbackBo;
import com.xyzc.start.mapper.HelpCommonMapper;
import com.xyzc.start.mapper.HelpFeedbackMapper;
import com.xyzc.start.service.IHelpPageService;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
@RequiredArgsConstructor
public class HelpPageServiceImpl implements IHelpPageService {

    private final HelpFeedbackMapper helpFeedbackmapper;
    private final HelpCommonMapper helpCommonMapper;

    /**
     * 提交反馈
     *
     * @param helpFeedbackBo
     */
    @Override
    public void submit(HelpFeedbackBo helpFeedbackBo) {
        HelpFeedback helpFeedback = new HelpFeedback();
        //todo ：记得使用 sysUser获取当前用户信息
        helpFeedback.setContent(helpFeedbackBo.getContent());
        boolean flag = helpFeedbackmapper.insert(helpFeedback) == 1;
        if (!flag) {
            throw new RuntimeException("反馈提交失败");
        }
    }


    /**
     * 对帮助文档打分
     *
     * @param id
     * @param status
     */
    @Override
    public void setHelper(Long id, Integer status) {
        HelpCommon helpCommon = helpCommonMapper.selectById(id);
        if (helpCommon == null) {
            throw new ServerException("反馈失败，请联系商家");
        }
        if (FeedbackConst.HELPER.equals(status)) {
            helpCommonMapper.update(new LambdaUpdateWrapper<HelpCommon>()
                    .set(HelpCommon::getHelpful, helpCommon.getHelpful() + 1)
                    .eq(HelpCommon::getId, id));
        } else {
            helpCommonMapper.update(new LambdaUpdateWrapper<HelpCommon>()
                    .set(HelpCommon::getNoHelp, helpCommon.getNoHelp() + 1)
                    .eq(HelpCommon::getId, id));
        }
    }

    /**
     * 根据id 查询能够返回的帮助文档
     *
     * @param id
     * @return
     */
    @Override
    public List<HelpCommon> queryHelpDocById(Long id) {
        //每次都只拿6个
        List<HelpCommon> helpDocs = helpCommonMapper.queryHelpDocListById(id != null ? id : 0);

        return helpDocs;
    }
}
