package com.xyzc.start.service.impl;

import com.xyzc.common.web.security.user.SecurityUser;
import com.xyzc.start.constant.BaseUserConst;
import com.xyzc.start.constant.MoreTypeConst;
import com.xyzc.start.domain.BaseUserCollect;
import com.xyzc.start.domain.query.BaseUserCollectQuery;
import com.xyzc.start.domain.vo.*;
import com.xyzc.start.mapper.BaseUserCollectMapper;
import com.xyzc.start.mapper.MerchantMapper;
import com.xyzc.start.service.IHomePageService;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.function.Function;
import java.util.stream.Collectors;

@Service
@RequiredArgsConstructor
public class HomePageServiceImpl implements IHomePageService {

    private final BaseUserCollectMapper baseUserCollectMapper;

    private final MerchantMapper merchantMapper;

    /**
     * 当前用户获取所有的历史应用和用户收藏的应用
     *
     * @return WebHomePageVo
     */
    @Override
    public WebHomePageVo getHomePage() {

        // 获取用户收藏应用 前8个
        List<BaseUserCollectAppVo> collectAppList = baseUserCollectMapper.queryCollectAppBy(SecurityUser.getUserId());

        // 获取用户历史应用 前8个
        List<BaseUserCollectAppVo> historyAppList = baseUserCollectMapper.queryHistoryAppBy(SecurityUser.getUserId());

        // 获取精选应用 前4个
        List<BaseUserSelectAppVo> carefulSelectAppList = baseUserCollectMapper.queryCarefulSelectAppBy(null, 4);
        // 以精选应用id为key,精选应用为value,生成一个map，并且去重
        Map<Long, BaseUserSelectAppVo> collect = carefulSelectAppList
                .stream()
                .collect(Collectors.toMap(BaseUserSelectAppVo::getAppId, Function.identity(), (k1, k2) -> k1));

        // 将map的id值转换为list
        List<Long> appIdList = new ArrayList<>(collect.keySet());
        List<BaseUserCollect> baseUserCollect = baseUserCollectMapper.queryCollectAppByUserIdAndAppId(SecurityUser.getUserId(), appIdList, BaseUserConst.COLLECT_APP);
        for (BaseUserCollect app : baseUserCollect){
            collect.get(app.getCollectId()).setIsCollect(app.getIsCollect());
        }

        //生成数据返回给视图
        WebHomePageVo webHomePageVo = new WebHomePageVo();
        webHomePageVo.setHistoryApps(historyAppList);
        webHomePageVo.setColletApps(collectAppList);
        webHomePageVo.setCarefullSelectApps(carefulSelectAppList);

        return webHomePageVo;
    }

    /**
     * 获取更多最近使用的应用
     *
     * @return
     */
    @Override
    public List<BaseUserCollectAppVo> getRecentlyUsed(Long appId) {
        // 获取最近使用应用

        return baseUserCollectMapper.queryHistoryAppBy(SecurityUser.getUserId());
    }

    /**
     * 获取联系信息
     *
     * @return
     */
    @Override
    public MerchantCancatVo getContact() {

        return merchantMapper.queryMerchantCancatById(SecurityUser.getUserId());
    }

    /**
     * 获取更多的收藏应用
     *
     * @param appId 应用id
     * @return
     */
    @Override
    public List<BaseUserCollectAppVo> getMoreCollect(Long appId) {
        // 获取跟多用户收藏应用
        return baseUserCollectMapper.queryCollectAppBy(SecurityUser.getUserId());
    }

    /**
     * 获取更多精选应用
     *
     * @param appId
     * @return
     */
    @Override
    public List<BaseUserSelectAppVo> getMoreSelector(Long appId) {
        // 获取更多精选应用
        List<BaseUserSelectAppVo> baseUserSelectAppVos = baseUserCollectMapper.queryCarefulSelectAppBy(appId, 10);

        // 以精选应用id未key,精选应用为value,生成一个map，并且去重
        Map<Long, BaseUserSelectAppVo> collect = baseUserSelectAppVos.stream().collect(Collectors.toMap(BaseUserSelectAppVo::getAppId, Function.identity(), (k1, k2) -> k1));

        // 将map的id值转换为list
        List<Long> ids = new ArrayList<>(collect.keySet());
        List<BaseUserCollect> baseUserCollect = baseUserCollectMapper.queryCollectAppByUserIdAndAppId(SecurityUser.getUserId(), ids, BaseUserConst.COLLECT_APP);
        for (BaseUserCollect app : baseUserCollect){
            collect.get(app.getCollectId()).setIsCollect(app.getIsCollect());
        }

        return baseUserSelectAppVos;

    }

    /**
     * 获取更多收藏
     *
     * @return List<BaseUserCollectVo>
     */
    @Override
    public List<BaseUserCollectVo> getMoreApps(BaseUserCollectQuery collectBo) {
        //todo : 需要获取当前用户信息
        Long userId = 123L;
        if (MoreTypeConst.COLLECT_DRAW_MODEL.equals(collectBo.getType())) {
            // todo: 下面还有一些别的字段需要确定
            //如果是收藏的绘画模型
            return baseUserCollectMapper.queryDrawModelByBo(collectBo, userId);

        } else if (MoreTypeConst.COLLECT_IMAGE.equals(collectBo.getType())) {
            //如果是收藏的图像
            return baseUserCollectMapper.queryImageByBo(collectBo, userId);
        }
        //剩下收藏的应用
        return baseUserCollectMapper.queryAbilityByBo(collectBo, userId);
    }

}
