package com.xyzc.start.service.impl;

import com.xyzc.common.core.exception.ErrorCode;
import com.xyzc.common.core.utils.AssertUtils;
import com.xyzc.common.core.utils.Result;
import com.xyzc.common.web.security.user.SecurityUser;
import com.xyzc.start.domain.MemberCard;
import com.xyzc.start.domain.Scheme;
import com.xyzc.start.domain.vo.*;
import com.xyzc.start.mapper.AiModelMapper;
import com.xyzc.start.mapper.EquityMapper;
import com.xyzc.start.mapper.MemberCardMapper;
import com.xyzc.start.mapper.SchemeMapper;
import com.xyzc.start.service.ISchemeService;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;
import org.xbill.DNS.dnssec.R;

import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

@Service
@RequiredArgsConstructor
public class SchemeServiceImpl implements ISchemeService {

    private final SchemeMapper schemeMapper;
    private final MemberCardMapper memberCardMapper;
    private final EquityMapper equityMapper;
    private final AiModelMapper aiModelMapper;

    /**
     * 获取当前方案
     *
     * @return
     */
    @Override
    public SchemeVo getCurrentMember() {
        List<SchemeVo> schemeVoList = schemeMapper.getCurrentMember();

        // 有且只有一个会员卡套餐生效
        //TODO 上线需要更改
        AssertUtils.isUnique(schemeVoList, ErrorCode.SCHEME_NOT_UNIQUE);
        SchemeVo schemeVo = schemeVoList.get(0);
        // 根据套餐查询会员卡
        List<MemberCardVo> memberCardVos = memberCardMapper.queryVoListBySchemeId(schemeVo.getId());
        // 获取列表中所有的会员卡id
        List<Long> memberCardIds = memberCardVos.stream().map(MemberCardVo::getId).toList();

        // 根据会员卡查询权益
        List<EquityVo> equityVos = equityMapper.queryVoByMemberCardIds(memberCardIds);
        // 将拿到的权益根据会员卡id分组
        Map<Long, List<EquityVo>> equityMap = equityVos.stream().collect(Collectors.groupingBy(EquityVo::getMemberCardId));
        // 将会员卡通过id和权益的会员卡id绑定
        memberCardVos.forEach(memberCardVo -> memberCardVo.setEquityList(equityMap.get(memberCardVo.getId())));

        // 将会员卡列表绑定到方案中
        schemeVo.setMemberCardList(memberCardVos);
        return schemeVo;
    }

    /**
     * 根据id获取燃料信息
     *
     * @param fuelId
     * @return
     */
    @Override
    public FuelPackageVo queryCurrentFuelById(Long fuelId) {

        return schemeMapper.queryFuelPackageById(SecurityUser.getUserId(), fuelId);
    }

    /**
     * 获取
     *
     * @param modelId 模型id
     * @return
     */
    @Override
    public List<AiModelVo> queryModelLawList(Long modelId) {

        return aiModelMapper.queryModelLawList(modelId);
    }

    /**
     * 根据会员卡id获取会员卡信息
     *
     * @param memberId
     * @return
     */
    @Override
    public MemberCardVo queryCurrentMemberById(Long memberId) {

        return schemeMapper.queryMemberCardByMemberId(SecurityUser.getUserId(), memberId);
    }

    /**
     * 获取当前生效的燃料方案
     *
     * @return
     */
    @Override
    public SchemeVo getCurrentFuel() {
        List<SchemeVo> currentFuel = schemeMapper.getCurrentFuel();
        // 有且只有一个会员卡套餐生效
        AssertUtils.isUnique(currentFuel, ErrorCode.SCHEME_NOT_UNIQUE);

        return currentFuel.get(0);
    }

}
